@@ -104,6 +104,8 @@ do { \
     } \
 } while(0)
 
+#define PMD_HUGE(pmd) ((pmd_val(pmd) & _PAGE_PSE) != 0)
+
 #ifdef pte_offset_atomic
 #define PTE_OFFSET(pte, pmd_p, pte_linear) \
 do { \
@@ -367,6 +369,7 @@ extern int ATI_API_CALL drm_mem_info1(char* buf, char** start, __ke_off_t offset
 extern int ATI_API_CALL drm_vm_info(char* buf, char** start, __ke_off_t offset, int len, int* eof, void* data);
 extern int ATI_API_CALL drm_clients_info(char* buf, char** start, __ke_off_t offset, int len, int* eof, void* data);
 extern int ATI_API_CALL firegl_lock_info(char* buf, char** start, __ke_off_t offset, int len, int* eof, void* data);
+extern int ATI_API_CALL firegl_ptm_info(char* buf, char** start, __ke_off_t offset, int len, int *eof, void *data);
 #ifdef DEBUG
 extern int ATI_API_CALL drm_bq_info(char* buf, char** start, __ke_off_t offset, int len, int* eof, void* data);
 #endif
@@ -420,6 +423,7 @@ extern void* ATI_API_CALL firegl_get_pagelist_from_vm(  struct vm_area_struct* v
 extern unsigned long ATI_API_CALL firegl_get_addr_from_vm(  struct vm_area_struct* vma);
 extern unsigned long ATI_API_CALL firegl_get_pagetable_page_from_vm(struct vm_area_struct* vma);
 extern void* ATI_API_CALL mc_heap_get_page(void *vma, unsigned long long offset);
+extern const unsigned int* ATI_API_CALL mc_heap_get_page_idx_list(void *pointer_to_mc_heap, unsigned int *number_of_pages);
 
 /*****************************************************************************/
 
@@ -485,7 +489,8 @@ extern void ATI_API_CALL KCL_MEM_IncPageCount_Mapping(void* page);
 extern int ATI_API_CALL KCL_MEM_VerifyReadAccess(void* addr, __ke_size_t size);
 extern int ATI_API_CALL KCL_MEM_VerifyWriteAccess(void* addr, __ke_size_t size);
 extern unsigned long ATI_API_CALL KCL_GetPageTableByVirtAddr(unsigned long virtual_addr, unsigned long* page_addr);
-extern __ke_dma_addr_t ATI_API_CALL KCL_GetDmaPhysAddr(unsigned long virtual_addr);
+extern int ATI_API_CALL KCL_LockUserPages(unsigned long vaddr, unsigned long* page_list, unsigned int page_cnt);
+extern void ATI_API_CALL KCL_UnlockUserPages(unsigned long* page_list, unsigned int page_cnt);
 extern int ATI_API_CALL KCL_TestAndClearPageDirtyFlag(unsigned long virtual_addr);
 extern unsigned long ATI_API_CALL KCL_MEM_AllocLinearAddrInterval(KCL_IO_FILE_Handle  file, unsigned long addr, unsigned long len, unsigned long pgoff);
 extern int ATI_API_CALL KCL_MEM_ReleaseLinearAddrInterval(unsigned long addr, unsigned long len);
